==> 0.2.3.tar.gz: lib/contentsquare.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:contentsquare/src/modules/screengraph/screengraph_explorer.dart';
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

export 'src/contentsquare_root.dart';

mixin _ContentsquarePlatformDelegate {
  static Future<String> _handleSnapshotRequest(
      {required String rootPath, required double pixelRatio}) async {
    List screengraph = await ScreengraphGenerator()
        .generateScreengraph(rootPath, pixelRatio: pixelRatio);
    return jsonEncode(screengraph);
  }
}

/// A class exposing Contentsquare SDK's API through its members.
class Contentsquare
    with _ContentsquarePlatformDelegate
    implements ContentsquarePlatform {
  @visibleForTesting
  // ignore: public_member_api_docs
  static MethodChannel channel = const MethodChannel('contentsquare');

  /// Initialize the Contentsquare SDK
  ///
  /// It registers a callback to handle the request for a snapshot from the _ContentsquarePlatformDelegate mixin
  static void initialize() {
    channel.setMethodCallHandler((MethodCall call) async {
      switch (call.method) {
        case 'requestFlutterSnapshot':
          return _ContentsquarePlatformDelegate._handleSnapshotRequest(
              rootPath: call.arguments['rootPath'] is String
                  ? call.arguments['rootPath']
                  : '',
              pixelRatio: call.arguments['pixelRatio'] is double
                  ? call.arguments['pixelRatio']
                  : 1);
      }
    });
  }

  /// Tracks a screen view with the given name.
  /// You should use this method to track every screen viewed by a user.
  ///
  /// See also
  /// [Screen views in developer documentation](https://docs.contentsquare.com/flutter/#track-screens)
  @override
  Future<void> send(String screenName) async =>
      channel.invokeMethod('send', {'screenName': screenName});

  /// Tracks the given transaction.
  /// Use this method to track purchases made by a user.
  ///
  /// You can use an use the [Currency.toStr] to get the String reprensentation for the `currency` parameter.
  @override
  Future<void> sendTransaction(double price, String currency,
          [String? transactionId]) async =>
      channel.invokeMethod('sendTransaction', {
        'price': price,
        'currency': currency,
        'transactionId': transactionId
      });

  /// Tracks a dynamic var.
  ///
  /// You should use either the `stringValue` parameter or the `intValue` parameter
  @override
  Future<void> sendDynamicVar(String key,
      {String? stringValue, int? intValue}) async {
    if (stringValue == null && intValue == null) {
      throw 'stringValue or intValue should be defined';
    }
    if (stringValue != null && intValue != null) {
      throw 'stringValue and intValue cannot be defined at the same time';
    }

    return channel.invokeMethod('sendDynamicVar', {
      'key': key,
      'stringValue': stringValue,
      'intValue': intValue,
    });
  }

  /// Opts the current user's device into being tracked.
  ///
  /// When this method is called tracking starts immediately.
  @override
  Future<void> optIn() async => channel.invokeMethod('optIn');

  /// Opts the current user's device out from being tracked.
  ///
  /// Immediately stops tracking the current device. The device will never be tracked again, unless the app is
  /// reinstalled, or you call the `optIn` method. In such case, the user will be tracked with a new user id and
  /// won't be linked to any previous activity.
  @override
  Future<void> optOut() async => channel.invokeMethod('optOut');

  /// Stops tracking current runtime and wipes user data.
  ///
  /// Any future tracked activity from the current user will have a new user id, and won't be linked to any past
  /// activity from this user. Tracking will resume on next app launch.
  @override
  Future<void> forgetMe() async => channel.invokeMethod('forgetMe');

  /// The anonymous id used by Contentsquare's SDK to track the current user.
  @override
  Future<String?> getUserId() async =>
      channel.invokeMethod<String>('getUserId');

  /// Stops any further tracking for the current runtime.
  ///
  /// Call this method if you need to pause tracking on some particularly sensitive part of your app. You can resume
  /// tracking at any point by calling [resumeTracking]. Tracking will also resume on next app launch.
  @override
  Future<void> stopTracking() async => channel.invokeMethod('stopTracking');

  /// Resumes tracking.
  ///
  /// Call this method when you want to resume tracking after having called `stopTracking`.
  @override
  Future<void> resumeTracking() async => channel.invokeMethod('resumeTracking');

  /// Consume touch event.
  ///
  /// Call this method when you want to track a touch event
  @override
  Future<void> sendTouchEvent(
          {required CSGesture type,
          required int version,
          required TouchEventData data}) async =>
      channel.invokeMethod('sendTouchEvent', {
        'body': jsonEncode({
          'type': type.toInt(),
          'version': version,
          'data': data.asMap(),
        })
      });
}

==> 0.3.0.tar.gz: lib/contentsquare.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:contentsquare/src/modules/screengraph/screengraph.dart';
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

export 'src/contentsquare_root.dart';

mixin _ContentsquarePlatformDelegate {
  static Future<String> _handleSnapshotRequest(
      {required String rootPath, required double pixelRatio}) async {
    final screengraph = await Screengraph()
        .toJson(rootPath, pixelRatio: pixelRatio);
    return jsonEncode(screengraph);
  }
}

/// A class exposing Contentsquare SDK's API through its members.
class Contentsquare
    with _ContentsquarePlatformDelegate
    implements ContentsquarePlatform {
  @visibleForTesting
  // ignore: public_member_api_docs
  static MethodChannel channel = const MethodChannel('contentsquare');

  /// Initialize the Contentsquare SDK
  ///
  /// It registers a callback to handle the request for a snapshot from the _ContentsquarePlatformDelegate mixin
  static void initialize() {
    channel.setMethodCallHandler((MethodCall call) async {
      switch (call.method) {
        case 'requestFlutterSnapshot':
          return _ContentsquarePlatformDelegate._handleSnapshotRequest(
              rootPath: call.arguments['rootPath'] is String
                  ? call.arguments['rootPath']
                  : '',
              pixelRatio: call.arguments['pixelRatio'] is double
                  ? call.arguments['pixelRatio']
                  : 1);
      }
    });
  }

  /// Tracks a screen view with the given name.
  /// You should use this method to track every screen viewed by a user.
  ///
  /// See also
  /// [Screen views in developer documentation](https://docs.contentsquare.com/flutter/#track-screens)
  @override
  Future<void> send(String screenName) async =>
      channel.invokeMethod('send', {'screenName': screenName});

  /// Tracks the given transaction.
  /// Use this method to track purchases made by a user.
  ///
  /// You can use an use the [Currency.toStr] to get the String reprensentation for the `currency` parameter.
  @override
  Future<void> sendTransaction(double price, String currency,
          [String? transactionId]) async =>
      channel.invokeMethod('sendTransaction', {
        'price': price,
        'currency': currency,
        'transactionId': transactionId
      });

  /// Tracks a dynamic var.
  ///
  /// You should use either the `stringValue` parameter or the `intValue` parameter
  @override
  Future<void> sendDynamicVar(String key,
      {String? stringValue, int? intValue}) async {
    if (stringValue == null && intValue == null) {
      throw 'stringValue or intValue should be defined';
    }
    if (stringValue != null && intValue != null) {
      throw 'stringValue and intValue cannot be defined at the same time';
    }

    return channel.invokeMethod('sendDynamicVar', {
      'key': key,
      'stringValue': stringValue,
      'intValue': intValue,
    });
  }

  /// Opts the current user's device into being tracked.
  ///
  /// When this method is called tracking starts immediately.
  @override
  Future<void> optIn() async => channel.invokeMethod('optIn');

  /// Opts the current user's device out from being tracked.
  ///
  /// Immediately stops tracking the current device. The device will never be tracked again, unless the app is
  /// reinstalled, or you call the `optIn` method. In such case, the user will be tracked with a new user id and
  /// won't be linked to any previous activity.
  @override
  Future<void> optOut() async => channel.invokeMethod('optOut');

  /// Stops tracking current runtime and wipes user data.
  ///
  /// Any future tracked activity from the current user will have a new user id, and won't be linked to any past
  /// activity from this user. Tracking will resume on next app launch.
  @override
  Future<void> forgetMe() async => channel.invokeMethod('forgetMe');

  /// The anonymous id used by Contentsquare's SDK to track the current user.
  @override
  Future<String?> getUserId() async =>
      channel.invokeMethod<String>('getUserId');

  /// Stops any further tracking for the current runtime.
  ///
  /// Call this method if you need to pause tracking on some particularly sensitive part of your app. You can resume
  /// tracking at any point by calling [resumeTracking]. Tracking will also resume on next app launch.
  @override
  Future<void> stopTracking() async => channel.invokeMethod('stopTracking');

  /// Resumes tracking.
  ///
  /// Call this method when you want to resume tracking after having called `stopTracking`.
  @override
  Future<void> resumeTracking() async => channel.invokeMethod('resumeTracking');

  /// Consume touch event.
  ///
  /// Call this method when you want to track a touch event
  @override
  Future<void> sendTouchEvent(
          {required CSGesture type,
          required int version,
          required TouchEventData data}) async =>
      channel.invokeMethod('sendTouchEvent', {
        'body': jsonEncode({
          'type': type.toInt(),
          'version': version,
          'data': data.asMap(),
        })
      });
}
